import React, { useState, useEffect } from "react";
import Body from "./Body";
import SearchBar from "./SearchBar";
import useFetch from "../hooks/useFetch";
import "../styleing/layout.css";

const my_key = process.env.REACT_APP_API_KEY;

const Layout = () => {
  const [filteredData, setFilteredData] = useState([]);
  const [currentPage, setCurrentPage] = useState(1);

  const { data, loading, error } = useFetch(my_key);

  useEffect(() => {
    if (data) {
      setFilteredData(data);
    }
  }, [data]);

  const handleSearch = (searchTerm) => {
    if (!searchTerm) {
      setFilteredData(data);
    } else {
      const filtered = data?.filter(
        (post) =>
          post?.title?.toLowerCase().includes(searchTerm?.toLowerCase()) ||
          post?.body?.toLowerCase().includes(searchTerm?.toLowerCase())
      );
      if (filtered?.length > 0) {
        setFilteredData(filtered);
      } else {
        setFilteredData([]);
      }
      setCurrentPage(1);
    }
  };

  if (loading) {
    return <div>Loading....</div>;
  }
  if (error) {
    return <div>Error: {error}</div>;
  }
  return (
    <div className="contentPage">
      <div className="header">
        <h2 className="heading">Latest Blogs</h2>
        <SearchBar onSearch={handleSearch} />
      </div>
      <div className="body">
        <Body
          filteredData={filteredData}
          setFilteredData={setFilteredData}
          currentPage={currentPage}
          setCurrentPage={setCurrentPage}
        />
      </div>
    </div>
  );
};

export default Layout;
